# W&T USB Redirector Software for Linux

This archive contains the W&T USB Redirector software for Linux by Wiesemann & Theis GmbH. It is suitable for both i686 (32 bit) and x86_64 (64 bit) architectures.

## Installation

To install the W&T USB Redirector Software for Linux on your distribution, please follow the steps below:

1. Unpack the archive to a location of your choice

    `tar -xf usb-redirector_v*.tar.gz`
2. Change the working directory to the unpacked directory.

3. Run the install script with suitable permissions 

    `sudo ./install.sh`. 

    This script will also check whether your system is supported or not.

4. Afterwards, the `usb-redirector` command is available on your terminal.

If you want to start the USB Redirector daemon at system start and your system supports `systemd`, the install script allows to automatically insert a suitable service for you. Alternatively, you can use the template service file `usb-redirector-daemon.service` to manually create a service.

If you want to automatically plug a USB Device when booting, you can use the template service file `usb-redirector-plug-devices.service` to create an additional service. Save your systemd service file at the appropriate place, e.g. `/etc/systemd/user/usb-redirector-plug-devices.service`, and enable it using `systemctl enable usb-redirector-plug-devices.service`.

## System Requirements

The USB Redirector needs the `vhci_hcd` kernel module as well as `usbip` to be installed.

## Usage

### Daemon

If you installed the USB Redirector via the systemd services, you can control the daemon process via `systemctl` commands. Typically you would control the daemon using the following command line:

`systemctl [start|stop|status|restart] usb-redirector-daemon.service`. 

For manual control and testing purposes you can start the daemon using the 

`usb-redirector daemon` 

command. If you want the daemon to stay in the foreground (e.g. to view the output messages), you may use the `-f` option, i.e.

`usb-redirector daemon -f` 

If you need to stop a daemon running in the background and not controlled by `systemd`, you need to first find its process id (PID), e.g. by the following command

`sudo ps -aux | grep usb-redirector` 

Using the PID the process can now be killed, e.g. using

`kill -9 <pid>`

### Client

You can use 

`usb-redirector -h`

to display a general help listing all commands. The help texts for specific commands can be displayed using 

`usb-redirector <command> -h` (e. g. `usb-redirector scan -h`).

The available commands alongside a brief overview are listed below.

##### scan

This command can be used to scan the network for connected USB Servers. Should your host be connected to multiple networks, the appropriate network adapter can be supplied via the command line.

```
$: usb-redirector scan ens192
IP address      | MAC           | System name       | Fw vers | Part number | Port
----------------------------------------------------------------------------------
10.40.28.65     | 00c03d:08e404 | USB-Server-08e404 | 1.37    | 53663       | 32032
10.40.28.63     | 00c03d:096103 | USB-Server-096103 | 1.10    | 53665       | 32032
```

##### list

The `list` command can be used to retrieve a list of connected USB devices present on a USB Server. The command supports passing more than one USB Server at once. Should you have configured a non standard TCP port for the USB Server, you can either supply the port via the `-p` option or using the standard `<IP>:<Port>` notation.

```
$: usb-redirector list 10.40.28.82 10.40.41.42:3333
Server IP       | USB port   | Device name          | Plugged to
---------------------------------------------------------------------
10.40.28.82     | 1.3        | USB Cable 2          | 10.40.28.32
10.40.41.42     | 1          | USB <> RS232 Cable 2 | 
```

##### status

The `status` command can be used to display the currently plugged USB devices. Additionally, the current connection state will be displayed.

```
$: usb-redirector status
Host            | USB port | Device name          | Speed | Status
-----------------------------------------------------------------------
10.40.28.82     | 1.3      | USB Cable 2          | (fs)  | Working
```

##### plug

The `plug` command is used to attach a remote USB device to the local computer. Both the IP address of the corresponding USB Server and the port need to be provided

```
usb-redirector plug 10.40.28.82 1.3
```

On success, the command will not print any message. Should the device already be plugged by another computer, the USB Redirector will print a warning but still insert the device into the local plug list. The USB Redirector will then periodically check wether the device can be plugged.

##### unplug

The `unplug` command uses the same notation as the `plug` command and can be used to remove a remote device from the local computer.

```
usb-redirector unplug 10.40.28.82 1.3
```

Additionally, all locally plugged devices can be removed at once using the special command

```
usb-redirector unplug all
```

## License & Copyright

For license and copyright information please refer to the "COPYRIGHT" file.

## Support

For further questions please contact Wiesemann & Theis GmbH:

Wiesemann & Theis GmbH

Porschestr. 12

42279 Wuppertal

Tel.: +49(0)202-2680-110 (Mo-Fr, 8:00-17:00)

Fax: +49(0)202-2680-265

info@wut.de
